@@ -74,45 +74,8 @@ def check_server_certificate(cert, key, cert_path, args, port, auto=False):
         lang = ob.Get('os_locale_locale')[:2]
 
         host_name = socket.getfqdn()
-        if c.lower() in ['n', 'no']:
-            name.CN = host_name  # (Common Name);
-            name.OU = 'www.calculate-linux.ru'  # (Organization Unit);
-            name.O = 'calculate-linux'  # (Organization Name);
-            name.L = host_name + ':' + str(port)  # (Locality Name);
-            name.ST = 'Spb'  # (State Name);
-            name.C = lang  # (Country);
-        else:
-            print _('Do not use spaces or tabs.')
-            host_name = socket.getfqdn()
-            name.CN = raw_input(_('Hostname [%s] : ') % host_name)
-            if name.CN in ['', None]:
-                name.CN = host_name
-            name.OU = raw_input(_('Organization unit: '))
-            if not name.OU:
-                name.OU = ''
-            else:
-                name.OU.replace(' ', '_').replace('\t', '_')
-            name.O = raw_input(_('Organization name: '))
-            if not name.O:
-                name.O = ''
-            else:
-                name.O.replace(' ', '_').replace('\t', '_')
-            network = _('Full network address (host:port)')
-            name.L = raw_input(network + ' [%s:%d]: ' % (host_name, port))
-            if name.L in ['', None]:
-                name.L = host_name + ':' + str(port)
-            name.ST = raw_input(_('City: '))
-            if not name.ST:
-                name.ST = ''
-            else:
-                name.ST.replace(' ', '_').replace('\t', '_')
-            name.C = raw_input(_('Country (two letters only!) [%s]: ') % lang)
-            if not name.C:
-                name.C = lang
-
         from create_cert import (passphrase_callback, generateRSAKey,
-                                 makePKey, makeCert)
-
+                                 makePKey, CreateCertError, create_selfsigned_ca)
         # Generating public key
         rsa = generateRSAKey()
         rsa.save_key(cert_path + '/root.key' + '_pub', cipher=None,
@@ -123,23 +86,48 @@ def check_server_certificate(cert, key, cert_path, args, port, auto=False):
         pkey.save_key(cert_path + '/root.key', cipher=None,
                       callback=passphrase_callback)
 
-        # Generating request
-        #        req = makeRequest(rsa, pkey, host_name, port)
-        req = X509.Request()
-        req.set_version(req.get_version())
-        req.set_pubkey(pkey)
-        req.set_subject_name(name)
+        name = {}
 
-        ext1 = X509.new_extension('Comment', 'Auto Generated')
-        extstack = X509.X509_Extension_Stack()
-        extstack.push(ext1)
-        req.add_extensions(extstack)
-        req.sign(pkey, 'md5')
-        req.save_pem(cert_path + '/root.csr')
+        if c.lower() in ['n', 'no']:
+            name['CN'] = host_name  # (Common Name);
+            name['OU'] = 'www.calculate-linux.ru'  # (Organization Unit);
+            name['O'] = 'calculate-linux'  # (Organization Name);
+            name['L'] = host_name + ':' + str(port)  # (Locality Name);
+            name['ST'] = 'Spb'  # (State Name);
+            name['C'] = lang  # (Country);
+        else:
+            print _('Do not use spaces or tabs.')
+            host_name = socket.getfqdn()
+            name['CN'] = raw_input(_('Hostname [%s] : ') % host_name)
+            if name['CN'] in ['', None]:
+                name['CN'] = host_name
+            name['OU'] = raw_input(_('Organization unit: '))
+            if not name['OU']:
+                name['OU'] = ''
+            else:
+                name['OU'] = name['OU'].replace(' ', '_').replace('\t', '_')
+            name['O'] = raw_input(_('Organization name: '))
+            if not name['O']:
+                name['O'] = ''
+            else:
+                name['O'] = name['O'].replace(' ', '_').replace('\t', '_')
+            network = _('Full network address (host:port)')
+            name['L'] = raw_input(network + ' [%s:%d]: ' % (host_name, port))
+            if name['L'] in ['', None]:
+                name['L'] = host_name + ':' + str(port)
+            name['ST'] = raw_input(_('City: '))
+            if not name['ST']:
+                name['ST'] = ''
+            else:
+                name['ST'] = name['ST'].replace(' ', '_').replace('\t', '_')
+            name['C'] = raw_input(_('Country (two letters only!) [%s]: ') % lang)
+            if not name['C']:
+                name['C'] = lang
 
-        # Generating Certificate
-        cert = makeCert(req, pkey, name)
-        cert.save_pem(cert_path + '/root.crt')
+        try:
+            create_selfsigned_ca(name, cert_path + '/root.key', cert_path + '/root.crt')
+        except CreateCertError:
+            print (_('Failed to create root certificate'))
 
         # add certificate in trusted
         try:
@@ -720,18 +708,13 @@ def sing_req_by_server(id_client_req, cert_path, data_path, auto=False,
         if os.path.exists(config):
             os.unlink(config)
 
-        from M2Crypto import X509, EVP
+        from create_cert import sign_client_certifacation_request
 
-        sr_cert = X509.load_cert(server_cert)
-
-        sr_key_inst = EVP.load_key(server_key)
-        cl_req_inst = X509.load_request(cl_req)
-
-        from create_cert import makeCert
-
-        cl_cert_inst = makeCert(cl_req_inst, sr_key_inst, sr_cert.get_issuer(),
-                                client_cert=True, group=group_name)
-        cl_cert_inst.save_pem(cl_cert)
+        try:
+            sign_client_certifacation_request(
+                server_key, server_cert, cl_req, cl_cert, group_name)
+        except CreateCertError:
+            print (_('Failed to sign client certificate'))
 
         # print 'startdate = ', startdate
         # cfg_text = (#"[ ssl_client ]\n"
